@@ -1,6 +1,6 @@
 import logging
 
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 
 _logger = logging.getLogger(__name__)
 
