@@ -1,4 +1,4 @@
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 from project.operation_execution.scheduled_operation_creator_worker import create_scheduled_operation_creator_worker
 
 
