@@ -1,7 +1,7 @@
 import uvicorn
 
 from project.core.settings import get_cached_settings
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 
 
 def __command():
