@@ -5,7 +5,7 @@ import aiohttp.web
 from aiogram.webhook.aiohttp_server import SimpleRequestHandler, setup_application
 
 from project.core.settings import get_cached_settings
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 from project.tg_bot.tg_bot import get_cached_tg_bot
 from project.tg_bot.tg_bot_dispatcher import create_tg_bot_dispatcher
 
